# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .domain_manager_status_service_pb2 import DomainManagerStatusRequest, DomainManagerStatusResponse

__all__ = [
    "DomainManagerStatusServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class DomainManagerStatusServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _DomainManagerStatusServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _DomainManagerStatusServiceAsyncStub: ...  # type: ignore
    def DomainManagerStatus(self, __1: DomainManagerStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DomainManagerStatusResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, DomainManagerStatusResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _DomainManagerStatusServiceBlockingStub(DomainManagerStatusServiceStub):
    def DomainManagerStatus(self, __1: DomainManagerStatusRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> DomainManagerStatusResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _DomainManagerStatusServiceAsyncStub(DomainManagerStatusServiceStub):
    def DomainManagerStatus(self, __1: DomainManagerStatusRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, DomainManagerStatusResponse]: ...  # type: ignore



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_aggregation_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_aggregation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/topology/admin/v30/topology_aggregation_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd8\x01\n\x12ListPartiesRequest\x12/\n\x05\x61s_of\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x61sOf\x12\x14\n\x05limit\x18\x02 \x01(\x05R\x05limit\x12)\n\x10synchronizer_ids\x18\x03 \x03(\tR\x0fsynchronizerIds\x12!\n\x0c\x66ilter_party\x18\x04 \x01(\tR\x0b\x66ilterParty\x12-\n\x12\x66ilter_participant\x18\x05 \x01(\tR\x11\x66ilterParticipant\"\xe6\x05\n\x13ListPartiesResponse\x12`\n\x07results\x18\x02 \x03(\x0b\x32\x46.com.digitalasset.canton.topology.admin.v30.ListPartiesResponse.ResultR\x07results\x1a\xec\x04\n\x06Result\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x83\x01\n\x0cparticipants\x18\x02 \x03(\x0b\x32_.com.digitalasset.canton.topology.admin.v30.ListPartiesResponse.Result.ParticipantSynchronizersR\x0cparticipants\x1a\xc5\x03\n\x18ParticipantSynchronizers\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x9d\x01\n\rsynchronizers\x18\x02 \x03(\x0b\x32w.com.digitalasset.canton.topology.admin.v30.ListPartiesResponse.Result.ParticipantSynchronizers.SynchronizerPermissionsR\rsynchronizers\x1a\xdf\x01\n\x17SynchronizerPermissions\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x61\n\npermission\x18\x02 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\x12\x38\n\x18physical_synchronizer_id\x18\x03 \x01(\tR\x16physicalSynchronizerId\"\xec\x01\n\x14ListKeyOwnersRequest\x12/\n\x05\x61s_of\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x61sOf\x12\x14\n\x05limit\x18\x02 \x01(\x05R\x05limit\x12)\n\x10synchronizer_ids\x18\x03 \x03(\tR\x0fsynchronizerIds\x12\x31\n\x15\x66ilter_key_owner_type\x18\x04 \x01(\tR\x12\x66ilterKeyOwnerType\x12/\n\x14\x66ilter_key_owner_uid\x18\x05 \x01(\tR\x11\x66ilterKeyOwnerUid\"\xc1\x03\n\x15ListKeyOwnersResponse\x12\x62\n\x07results\x18\x01 \x03(\x0b\x32H.com.digitalasset.canton.topology.admin.v30.ListKeyOwnersResponse.ResultR\x07results\x1a\xc3\x02\n\x06Result\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x1b\n\tkey_owner\x18\x02 \x01(\tR\x08keyOwner\x12W\n\x0csigning_keys\x18\x03 \x03(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\x0bsigningKeys\x12`\n\x0f\x65ncryption_keys\x18\x04 \x03(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.EncryptionPublicKeyR\x0e\x65ncryptionKeys\x12\x38\n\x18physical_synchronizer_id\x18\x05 \x01(\tR\x16physicalSynchronizerId2\xc4\x02\n\x1aTopologyAggregationService\x12\x8e\x01\n\x0bListParties\x12>.com.digitalasset.canton.topology.admin.v30.ListPartiesRequest\x1a?.com.digitalasset.canton.topology.admin.v30.ListPartiesResponse\x12\x94\x01\n\rListKeyOwners\x12@.com.digitalasset.canton.topology.admin.v30.ListKeyOwnersRequest\x1a\x41.com.digitalasset.canton.topology.admin.v30.ListKeyOwnersResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_aggregation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_LISTPARTIESREQUEST']._serialized_start=261
  _globals['_LISTPARTIESREQUEST']._serialized_end=477
  _globals['_LISTPARTIESRESPONSE']._serialized_start=480
  _globals['_LISTPARTIESRESPONSE']._serialized_end=1222
  _globals['_LISTPARTIESRESPONSE_RESULT']._serialized_start=602
  _globals['_LISTPARTIESRESPONSE_RESULT']._serialized_end=1222
  _globals['_LISTPARTIESRESPONSE_RESULT_PARTICIPANTSYNCHRONIZERS']._serialized_start=769
  _globals['_LISTPARTIESRESPONSE_RESULT_PARTICIPANTSYNCHRONIZERS']._serialized_end=1222
  _globals['_LISTPARTIESRESPONSE_RESULT_PARTICIPANTSYNCHRONIZERS_SYNCHRONIZERPERMISSIONS']._serialized_start=999
  _globals['_LISTPARTIESRESPONSE_RESULT_PARTICIPANTSYNCHRONIZERS_SYNCHRONIZERPERMISSIONS']._serialized_end=1222
  _globals['_LISTKEYOWNERSREQUEST']._serialized_start=1225
  _globals['_LISTKEYOWNERSREQUEST']._serialized_end=1461
  _globals['_LISTKEYOWNERSRESPONSE']._serialized_start=1464
  _globals['_LISTKEYOWNERSRESPONSE']._serialized_end=1913
  _globals['_LISTKEYOWNERSRESPONSE_RESULT']._serialized_start=1590
  _globals['_LISTKEYOWNERSRESPONSE_RESULT']._serialized_end=1913
  _globals['_TOPOLOGYAGGREGATIONSERVICE']._serialized_start=1916
  _globals['_TOPOLOGYAGGREGATIONSERVICE']._serialized_end=2240
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="PackageFeature")


@_attrs_define
class PackageFeature:
    """
    Attributes:
        max_vetted_packages_page_size (int): The maximum number of vetted packages the server can return in a single
            response (page) when listing them.
    """

    max_vetted_packages_page_size: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        max_vetted_packages_page_size = self.max_vetted_packages_page_size

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "maxVettedPackagesPageSize": max_vetted_packages_page_size,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        max_vetted_packages_page_size = d.pop("maxVettedPackagesPageSize")

        package_feature = cls(
            max_vetted_packages_page_size=max_vetted_packages_page_size,
        )

        package_feature.additional_properties = d
        return package_feature

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from . import value_pb2 as _value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TransactionShape(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    TRANSACTION_SHAPE_UNSPECIFIED: _ClassVar[TransactionShape]
    TRANSACTION_SHAPE_ACS_DELTA: _ClassVar[TransactionShape]
    TRANSACTION_SHAPE_LEDGER_EFFECTS: _ClassVar[TransactionShape]
TRANSACTION_SHAPE_UNSPECIFIED: TransactionShape
TRANSACTION_SHAPE_ACS_DELTA: TransactionShape
TRANSACTION_SHAPE_LEDGER_EFFECTS: TransactionShape

class Filters(_message.Message):
    __slots__ = ("cumulative",)
    CUMULATIVE_FIELD_NUMBER: _ClassVar[int]
    cumulative: _containers.RepeatedCompositeFieldContainer[CumulativeFilter]
    def __init__(self, cumulative: _Optional[_Iterable[_Union[CumulativeFilter, _Mapping]]] = ...) -> None: ...

class CumulativeFilter(_message.Message):
    __slots__ = ("wildcard_filter", "interface_filter", "template_filter")
    WILDCARD_FILTER_FIELD_NUMBER: _ClassVar[int]
    INTERFACE_FILTER_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_FILTER_FIELD_NUMBER: _ClassVar[int]
    wildcard_filter: WildcardFilter
    interface_filter: InterfaceFilter
    template_filter: TemplateFilter
    def __init__(self, wildcard_filter: _Optional[_Union[WildcardFilter, _Mapping]] = ..., interface_filter: _Optional[_Union[InterfaceFilter, _Mapping]] = ..., template_filter: _Optional[_Union[TemplateFilter, _Mapping]] = ...) -> None: ...

class WildcardFilter(_message.Message):
    __slots__ = ("include_created_event_blob",)
    INCLUDE_CREATED_EVENT_BLOB_FIELD_NUMBER: _ClassVar[int]
    include_created_event_blob: bool
    def __init__(self, include_created_event_blob: bool = ...) -> None: ...

class InterfaceFilter(_message.Message):
    __slots__ = ("interface_id", "include_interface_view", "include_created_event_blob")
    INTERFACE_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_INTERFACE_VIEW_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_CREATED_EVENT_BLOB_FIELD_NUMBER: _ClassVar[int]
    interface_id: _value_pb2.Identifier
    include_interface_view: bool
    include_created_event_blob: bool
    def __init__(self, interface_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., include_interface_view: bool = ..., include_created_event_blob: bool = ...) -> None: ...

class TemplateFilter(_message.Message):
    __slots__ = ("template_id", "include_created_event_blob")
    TEMPLATE_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_CREATED_EVENT_BLOB_FIELD_NUMBER: _ClassVar[int]
    template_id: _value_pb2.Identifier
    include_created_event_blob: bool
    def __init__(self, template_id: _Optional[_Union[_value_pb2.Identifier, _Mapping]] = ..., include_created_event_blob: bool = ...) -> None: ...

class EventFormat(_message.Message):
    __slots__ = ("filters_by_party", "filters_for_any_party", "verbose")
    class FiltersByPartyEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: Filters
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[Filters, _Mapping]] = ...) -> None: ...
    FILTERS_BY_PARTY_FIELD_NUMBER: _ClassVar[int]
    FILTERS_FOR_ANY_PARTY_FIELD_NUMBER: _ClassVar[int]
    VERBOSE_FIELD_NUMBER: _ClassVar[int]
    filters_by_party: _containers.MessageMap[str, Filters]
    filters_for_any_party: Filters
    verbose: bool
    def __init__(self, filters_by_party: _Optional[_Mapping[str, Filters]] = ..., filters_for_any_party: _Optional[_Union[Filters, _Mapping]] = ..., verbose: bool = ...) -> None: ...

class TransactionFormat(_message.Message):
    __slots__ = ("event_format", "transaction_shape")
    EVENT_FORMAT_FIELD_NUMBER: _ClassVar[int]
    TRANSACTION_SHAPE_FIELD_NUMBER: _ClassVar[int]
    event_format: EventFormat
    transaction_shape: TransactionShape
    def __init__(self, event_format: _Optional[_Union[EventFormat, _Mapping]] = ..., transaction_shape: _Optional[_Union[TransactionShape, str]] = ...) -> None: ...

class TopologyFormat(_message.Message):
    __slots__ = ("include_participant_authorization_events",)
    INCLUDE_PARTICIPANT_AUTHORIZATION_EVENTS_FIELD_NUMBER: _ClassVar[int]
    include_participant_authorization_events: ParticipantAuthorizationTopologyFormat
    def __init__(self, include_participant_authorization_events: _Optional[_Union[ParticipantAuthorizationTopologyFormat, _Mapping]] = ...) -> None: ...

class ParticipantAuthorizationTopologyFormat(_message.Message):
    __slots__ = ("parties",)
    PARTIES_FIELD_NUMBER: _ClassVar[int]
    parties: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, parties: _Optional[_Iterable[str]] = ...) -> None: ...

class UpdateFormat(_message.Message):
    __slots__ = ("include_transactions", "include_reassignments", "include_topology_events")
    INCLUDE_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_REASSIGNMENTS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_TOPOLOGY_EVENTS_FIELD_NUMBER: _ClassVar[int]
    include_transactions: TransactionFormat
    include_reassignments: EventFormat
    include_topology_events: TopologyFormat
    def __init__(self, include_transactions: _Optional[_Union[TransactionFormat, _Mapping]] = ..., include_reassignments: _Optional[_Union[EventFormat, _Mapping]] = ..., include_topology_events: _Optional[_Union[TopologyFormat, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import sequencing_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRcom/digitalasset/canton/sequencer/admin/v30/sequencer_initialization_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x35\x63om/digitalasset/canton/protocol/v30/sequencing.proto\"\xd6\x01\n*InitializeSequencerFromGenesisStateRequest\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12{\n\x17synchronizer_parameters\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.StaticSynchronizerParametersR\x16synchronizerParameters\"M\n+InitializeSequencerFromGenesisStateResponse\x12\x1e\n\nreplicated\x18\x01 \x01(\x08R\nreplicated\"\xd5\x01\n)InitializeSequencerFromPredecessorRequest\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12{\n\x17synchronizer_parameters\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.StaticSynchronizerParametersR\x16synchronizerParameters\",\n*InitializeSequencerFromPredecessorResponse\"Z\n-InitializeSequencerFromOnboardingStateRequest\x12)\n\x10onboarding_state\x18\x01 \x01(\x0cR\x0fonboardingState\"P\n.InitializeSequencerFromOnboardingStateResponse\x12\x1e\n\nreplicated\x18\x01 \x01(\x08R\nreplicated\"\xd8\x01\n,InitializeSequencerFromGenesisStateV2Request\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12{\n\x17synchronizer_parameters\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.StaticSynchronizerParametersR\x16synchronizerParameters\"O\n-InitializeSequencerFromGenesisStateV2Response\x12\x1e\n\nreplicated\x18\x01 \x01(\x08R\nreplicated\"\\\n/InitializeSequencerFromOnboardingStateV2Request\x12)\n\x10onboarding_state\x18\x01 \x01(\x0cR\x0fonboardingState\"R\n0InitializeSequencerFromOnboardingStateV2Response\x12\x1e\n\nreplicated\x18\x01 \x01(\x08R\nreplicated2\x8c\t\n\x1eSequencerInitializationService\x12\xda\x01\n#InitializeSequencerFromGenesisState\x12W.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromGenesisStateRequest\x1aX.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromGenesisStateResponse(\x01\x12\xe3\x01\n&InitializeSequencerFromOnboardingState\x12Z.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromOnboardingStateRequest\x1a[.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromOnboardingStateResponse(\x01\x12\xd7\x01\n\"InitializeSequencerFromPredecessor\x12V.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromPredecessorRequest\x1aW.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromPredecessorResponse(\x01\x12\xe0\x01\n%InitializeSequencerFromGenesisStateV2\x12Y.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromGenesisStateV2Request\x1aZ.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromGenesisStateV2Response(\x01\x12\xe9\x01\n(InitializeSequencerFromOnboardingStateV2\x12\\.com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromOnboardingStateV2Request\x1a].com.digitalasset.canton.sequencer.admin.v30.InitializeSequencerFromOnboardingStateV2Response(\x01\x42\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATEREQUEST']._serialized_start=187
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATEREQUEST']._serialized_end=401
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATERESPONSE']._serialized_start=403
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATERESPONSE']._serialized_end=480
  _globals['_INITIALIZESEQUENCERFROMPREDECESSORREQUEST']._serialized_start=483
  _globals['_INITIALIZESEQUENCERFROMPREDECESSORREQUEST']._serialized_end=696
  _globals['_INITIALIZESEQUENCERFROMPREDECESSORRESPONSE']._serialized_start=698
  _globals['_INITIALIZESEQUENCERFROMPREDECESSORRESPONSE']._serialized_end=742
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATEREQUEST']._serialized_start=744
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATEREQUEST']._serialized_end=834
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATERESPONSE']._serialized_start=836
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATERESPONSE']._serialized_end=916
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATEV2REQUEST']._serialized_start=919
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATEV2REQUEST']._serialized_end=1135
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATEV2RESPONSE']._serialized_start=1137
  _globals['_INITIALIZESEQUENCERFROMGENESISSTATEV2RESPONSE']._serialized_end=1216
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATEV2REQUEST']._serialized_start=1218
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATEV2REQUEST']._serialized_end=1310
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATEV2RESPONSE']._serialized_start=1312
  _globals['_INITIALIZESEQUENCERFROMONBOARDINGSTATEV2RESPONSE']._serialized_end=1394
  _globals['_SEQUENCERINITIALIZATIONSERVICE']._serialized_start=1397
  _globals['_SEQUENCERINITIALIZATIONSERVICE']._serialized_end=2561
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="DisclosedContract")


@_attrs_define
class DisclosedContract:
    """An additional contract that is used to resolve
    contract & contract key lookups.

        Attributes:
            contract_id (str): The contract id

                If provided, used to validate the contract id of the contract serialized in the created_event_blob.
                Optional
            created_event_blob (str): Opaque byte string containing the complete payload required by the Daml engine
                to reconstruct a contract not known to the receiving participant.
                Required
            synchronizer_id (str): The ID of the synchronizer where the contract is currently assigned
                Optional
            template_id (str | Unset): The template id of the contract.
                The identifier uses the package-id reference format.

                If provided, used to validate the template id of the contract serialized in the created_event_blob.
                Optional
    """

    contract_id: str
    created_event_blob: str
    synchronizer_id: str
    template_id: str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        contract_id = self.contract_id

        created_event_blob = self.created_event_blob

        synchronizer_id = self.synchronizer_id

        template_id = self.template_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "contractId": contract_id,
                "createdEventBlob": created_event_blob,
                "synchronizerId": synchronizer_id,
            }
        )
        if template_id is not UNSET:
            field_dict["templateId"] = template_id

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        contract_id = d.pop("contractId")

        created_event_blob = d.pop("createdEventBlob")

        synchronizer_id = d.pop("synchronizerId")

        template_id = d.pop("templateId", UNSET)

        disclosed_contract = cls(
            contract_id=contract_id,
            created_event_blob=created_event_blob,
            synchronizer_id=synchronizer_id,
            template_id=template_id,
        )

        disclosed_contract.additional_properties = d
        return disclosed_contract

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.object_meta import ObjectMeta


T = TypeVar("T", bound="AllocatePartyRequest")


@_attrs_define
class AllocatePartyRequest:
    """Required authorization: ``HasRight(ParticipantAdmin) OR IsAuthenticatedIdentityProviderAdmin(identity_provider_id)``

    Attributes:
        party_id_hint (str): A hint to the participant which party ID to allocate. It can be
            ignored.
            Must be a valid PartyIdString (as described in ``value.proto``).
            Optional
        identity_provider_id (str): The id of the ``Identity Provider``
            Optional, if not set, assume the party is managed by the default identity provider or party is not hosted by the
            participant.
        synchronizer_id (str): The synchronizer, on which the party should be allocated.
            For backwards compatibility, this field may be omitted, if the participant is connected to only one
            synchronizer.
            Otherwise a synchronizer must be specified.
            Optional
        user_id (str): The user who will get the act_as rights to the newly allocated party.
            If set to an empty string (the default), no user will get rights to the party.
            Optional
        local_metadata (ObjectMeta | Unset): Represents metadata corresponding to a participant resource (e.g. a
            participant user or participant local information about a party).

            Based on ``ObjectMeta`` meta used in Kubernetes API.
            See https://github.com/kubernetes/apimachinery/blob/master/pkg/apis/meta/v1/generated.proto#L640
    """

    party_id_hint: str
    identity_provider_id: str
    synchronizer_id: str
    user_id: str
    local_metadata: ObjectMeta | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        party_id_hint = self.party_id_hint

        identity_provider_id = self.identity_provider_id

        synchronizer_id = self.synchronizer_id

        user_id = self.user_id

        local_metadata: dict[str, Any] | Unset = UNSET
        if not isinstance(self.local_metadata, Unset):
            local_metadata = self.local_metadata.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "partyIdHint": party_id_hint,
                "identityProviderId": identity_provider_id,
                "synchronizerId": synchronizer_id,
                "userId": user_id,
            }
        )
        if local_metadata is not UNSET:
            field_dict["localMetadata"] = local_metadata

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.object_meta import ObjectMeta

        d = dict(src_dict)
        party_id_hint = d.pop("partyIdHint")

        identity_provider_id = d.pop("identityProviderId")

        synchronizer_id = d.pop("synchronizerId")

        user_id = d.pop("userId")

        _local_metadata = d.pop("localMetadata", UNSET)
        local_metadata: ObjectMeta | Unset
        if isinstance(_local_metadata, Unset):
            local_metadata = UNSET
        else:
            local_metadata = ObjectMeta.from_dict(_local_metadata)

        allocate_party_request = cls(
            party_id_hint=party_id_hint,
            identity_provider_id=identity_provider_id,
            synchronizer_id=synchronizer_id,
            user_id=user_id,
            local_metadata=local_metadata,
        )

        allocate_party_request.additional_properties = d
        return allocate_party_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="CompletionStreamRequest")


@_attrs_define
class CompletionStreamRequest:
    """
    Attributes:
        user_id (str): Only completions of commands submitted with the same user_id will be visible in the stream.
            Must be a valid UserIdString (as described in ``value.proto``).
            Required unless authentication is used with a user token.
            In that case, the token's user-id will be used for the request's user_id.
        begin_exclusive (int): This optional field indicates the minimum offset for completions. This can be used to
            resume an earlier completion stream.
            If not set the ledger uses the ledger begin offset instead.
            If specified, it must be a valid absolute offset (positive integer) or zero (ledger begin offset).
            If the ledger has been pruned, this parameter must be specified and greater than the pruning offset.
        parties (list[str] | Unset): Non-empty list of parties whose data should be included.
            The stream shows only completions of commands for which at least one of the ``act_as`` parties is in the given
            set of parties.
            Must be a valid PartyIdString (as described in ``value.proto``).
            Required
    """

    user_id: str
    begin_exclusive: int
    parties: list[str] | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        user_id = self.user_id

        begin_exclusive = self.begin_exclusive

        parties: list[str] | Unset = UNSET
        if not isinstance(self.parties, Unset):
            parties = self.parties

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "userId": user_id,
                "beginExclusive": begin_exclusive,
            }
        )
        if parties is not UNSET:
            field_dict["parties"] = parties

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        user_id = d.pop("userId")

        begin_exclusive = d.pop("beginExclusive")

        parties = cast(list[str], d.pop("parties", UNSET))

        completion_stream_request = cls(
            user_id=user_id,
            begin_exclusive=begin_exclusive,
            parties=parties,
        )

        completion_stream_request.additional_properties = d
        return completion_stream_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ContractAuthenticationData(_message.Message):
    __slots__ = ("contract_salt", "creating_transaction_id", "relative_argument_suffixes")
    CONTRACT_SALT_FIELD_NUMBER: _ClassVar[int]
    CREATING_TRANSACTION_ID_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_ARGUMENT_SUFFIXES_FIELD_NUMBER: _ClassVar[int]
    contract_salt: bytes
    creating_transaction_id: bytes
    relative_argument_suffixes: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, contract_salt: _Optional[bytes] = ..., creating_transaction_id: _Optional[bytes] = ..., relative_argument_suffixes: _Optional[_Iterable[bytes]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/acs_import.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/acs_import.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>com/digitalasset/canton/admin/participant/v30/acs_import.proto\x12-com.digitalasset.canton.admin.participant.v30\"\xbe\x05\n\x1fRepresentativePackageIdOverride\x12\x91\x01\n\x11\x63ontract_override\x18\x01 \x03(\x0b\x32\x64.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverride.ContractOverrideEntryR\x10\x63ontractOverride\x12\x95\x01\n\x13package_id_override\x18\x02 \x03(\x0b\x32\x65.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverride.PackageIdOverrideEntryR\x11packageIdOverride\x12\x9b\x01\n\x15package_name_override\x18\x03 \x03(\x0b\x32g.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverride.PackageNameOverrideEntryR\x13packageNameOverride\x1a\x43\n\x15\x43ontractOverrideEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x44\n\x16PackageIdOverrideEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x46\n\x18PackageNameOverrideEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xa8\x01\n\x12\x43ontractImportMode\x12$\n CONTRACT_IMPORT_MODE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x43ONTRACT_IMPORT_MODE_ACCEPT\x10\x01\x12#\n\x1f\x43ONTRACT_IMPORT_MODE_VALIDATION\x10\x02\x12&\n\"CONTRACT_IMPORT_MODE_RECOMPUTATION\x10\x03\x42^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.acs_import_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_CONTRACTOVERRIDEENTRY']._loaded_options = None
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_CONTRACTOVERRIDEENTRY']._serialized_options = b'8\001'
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGEIDOVERRIDEENTRY']._loaded_options = None
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGEIDOVERRIDEENTRY']._serialized_options = b'8\001'
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGENAMEOVERRIDEENTRY']._loaded_options = None
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGENAMEOVERRIDEENTRY']._serialized_options = b'8\001'
  _globals['_CONTRACTIMPORTMODE']._serialized_start=819
  _globals['_CONTRACTIMPORTMODE']._serialized_end=987
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE']._serialized_start=114
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE']._serialized_end=816
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_CONTRACTOVERRIDEENTRY']._serialized_start=607
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_CONTRACTOVERRIDEENTRY']._serialized_end=674
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGEIDOVERRIDEENTRY']._serialized_start=676
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGEIDOVERRIDEENTRY']._serialized_end=744
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGENAMEOVERRIDEENTRY']._serialized_start=746
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGENAMEOVERRIDEENTRY']._serialized_end=816
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/package_reference.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/package_reference.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.com/daml/ledger/api/v2/package_reference.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"}\n\x10PackageReference\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12\'\n\x0fpackage_version\x18\x03 \x01(\tR\x0epackageVersion\"\x98\x02\n\rVettedPackage\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12L\n\x14valid_from_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12validFromInclusive\x12N\n\x15valid_until_exclusive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validUntilExclusive\x12!\n\x0cpackage_name\x18\x04 \x01(\tR\x0bpackageName\x12\'\n\x0fpackage_version\x18\x05 \x01(\tR\x0epackageVersion\"\xcc\x01\n\x0eVettedPackages\x12\x41\n\x08packages\x18\x01 \x03(\x0b\x32%.com.daml.ledger.api.v2.VettedPackageR\x08packages\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12\'\n\x0ftopology_serial\x18\x04 \x01(\rR\x0etopologySerial\"l\n\x13PriorTopologySerial\x12\x16\n\x05prior\x18\x01 \x01(\rH\x00R\x05prior\x12\x33\n\x08no_prior\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07noPriorB\x08\n\x06serialB\x94\x01\n\x16\x63om.daml.ledger.api.v2B\x1aPackageReferenceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.package_reference_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\032PackageReferenceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_PACKAGEREFERENCE']._serialized_start=136
  _globals['_PACKAGEREFERENCE']._serialized_end=261
  _globals['_VETTEDPACKAGE']._serialized_start=264
  _globals['_VETTEDPACKAGE']._serialized_end=544
  _globals['_VETTEDPACKAGES']._serialized_start=547
  _globals['_VETTEDPACKAGES']._serialized_end=751
  _globals['_PRIORTOPOLOGYSERIAL']._serialized_start=753
  _globals['_PRIORTOPOLOGYSERIAL']._serialized_end=861
# @@protoc_insertion_point(module_scope)



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from ...crypto.v30 import crypto_pb2 as _crypto_pb2
from . import sequencing_parameters_pb2 as _sequencing_parameters_pb2
from . import synchronizer_parameters_pb2 as _synchronizer_parameters_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Enums(_message.Message):
    __slots__ = ()
    class TopologyChangeOp(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TOPOLOGY_CHANGE_OP_UNSPECIFIED: _ClassVar[Enums.TopologyChangeOp]
        TOPOLOGY_CHANGE_OP_ADD_REPLACE: _ClassVar[Enums.TopologyChangeOp]
        TOPOLOGY_CHANGE_OP_REMOVE: _ClassVar[Enums.TopologyChangeOp]
    TOPOLOGY_CHANGE_OP_UNSPECIFIED: Enums.TopologyChangeOp
    TOPOLOGY_CHANGE_OP_ADD_REPLACE: Enums.TopologyChangeOp
    TOPOLOGY_CHANGE_OP_REMOVE: Enums.TopologyChangeOp
    class ParticipantPermission(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PARTICIPANT_PERMISSION_UNSPECIFIED: _ClassVar[Enums.ParticipantPermission]
        PARTICIPANT_PERMISSION_SUBMISSION: _ClassVar[Enums.ParticipantPermission]
        PARTICIPANT_PERMISSION_CONFIRMATION: _ClassVar[Enums.ParticipantPermission]
        PARTICIPANT_PERMISSION_OBSERVATION: _ClassVar[Enums.ParticipantPermission]
    PARTICIPANT_PERMISSION_UNSPECIFIED: Enums.ParticipantPermission
    PARTICIPANT_PERMISSION_SUBMISSION: Enums.ParticipantPermission
    PARTICIPANT_PERMISSION_CONFIRMATION: Enums.ParticipantPermission
    PARTICIPANT_PERMISSION_OBSERVATION: Enums.ParticipantPermission
    class TopologyMappingCode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        TOPOLOGY_MAPPING_CODE_UNSPECIFIED: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_NAMESPACE_DELEGATION: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_DECENTRALIZED_NAMESPACE_DEFINITION: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_OWNER_TO_KEY_MAPPING: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_TRUST_CERTIFICATE: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_PARTICIPANT_PERMISSION: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_PARTY_HOSTING_LIMITS: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_VETTED_PACKAGES: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_PARTY_TO_PARTICIPANT: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_PARAMETERS_STATE: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_MEDIATOR_SYNCHRONIZER_STATE: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_SEQUENCER_SYNCHRONIZER_STATE: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_SEQUENCING_DYNAMIC_PARAMETERS_STATE: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_PARTY_TO_KEY_MAPPING: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_MIGRATION_ANNOUNCEMENT: _ClassVar[Enums.TopologyMappingCode]
        TOPOLOGY_MAPPING_CODE_SEQUENCER_CONNECTION_SUCCESSOR: _ClassVar[Enums.TopologyMappingCode]
    TOPOLOGY_MAPPING_CODE_UNSPECIFIED: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_NAMESPACE_DELEGATION: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_DECENTRALIZED_NAMESPACE_DEFINITION: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_OWNER_TO_KEY_MAPPING: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_TRUST_CERTIFICATE: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_PARTICIPANT_PERMISSION: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_PARTY_HOSTING_LIMITS: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_VETTED_PACKAGES: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_PARTY_TO_PARTICIPANT: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_PARAMETERS_STATE: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_MEDIATOR_SYNCHRONIZER_STATE: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_SEQUENCER_SYNCHRONIZER_STATE: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_SEQUENCING_DYNAMIC_PARAMETERS_STATE: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_PARTY_TO_KEY_MAPPING: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_MIGRATION_ANNOUNCEMENT: Enums.TopologyMappingCode
    TOPOLOGY_MAPPING_CODE_SEQUENCER_CONNECTION_SUCCESSOR: Enums.TopologyMappingCode
    class ParticipantFeatureFlag(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        PARTICIPANT_FEATURE_FLAG_UNSPECIFIED: _ClassVar[Enums.ParticipantFeatureFlag]
        PARTICIPANT_FEATURE_FLAG_PV33_EXTERNAL_SIGNING_LOCAL_CONTRACT_IN_SUBVIEW: _ClassVar[Enums.ParticipantFeatureFlag]
    PARTICIPANT_FEATURE_FLAG_UNSPECIFIED: Enums.ParticipantFeatureFlag
    PARTICIPANT_FEATURE_FLAG_PV33_EXTERNAL_SIGNING_LOCAL_CONTRACT_IN_SUBVIEW: Enums.ParticipantFeatureFlag
    def __init__(self) -> None: ...

class NamespaceDelegation(_message.Message):
    __slots__ = ("namespace", "target_key", "is_root_delegation", "can_sign_all_mappings", "can_sign_all_but_namespace_delegations", "can_sign_specific_mapings")
    class CanSignAllMappings(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class CanSignAllButNamespaceDelegations(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class CanSignSpecificMappings(_message.Message):
        __slots__ = ("mappings",)
        MAPPINGS_FIELD_NUMBER: _ClassVar[int]
        mappings: _containers.RepeatedScalarFieldContainer[Enums.TopologyMappingCode]
        def __init__(self, mappings: _Optional[_Iterable[_Union[Enums.TopologyMappingCode, str]]] = ...) -> None: ...
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    TARGET_KEY_FIELD_NUMBER: _ClassVar[int]
    IS_ROOT_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    CAN_SIGN_ALL_MAPPINGS_FIELD_NUMBER: _ClassVar[int]
    CAN_SIGN_ALL_BUT_NAMESPACE_DELEGATIONS_FIELD_NUMBER: _ClassVar[int]
    CAN_SIGN_SPECIFIC_MAPINGS_FIELD_NUMBER: _ClassVar[int]
    namespace: str
    target_key: _crypto_pb2.SigningPublicKey
    is_root_delegation: bool
    can_sign_all_mappings: NamespaceDelegation.CanSignAllMappings
    can_sign_all_but_namespace_delegations: NamespaceDelegation.CanSignAllButNamespaceDelegations
    can_sign_specific_mapings: NamespaceDelegation.CanSignSpecificMappings
    def __init__(self, namespace: _Optional[str] = ..., target_key: _Optional[_Union[_crypto_pb2.SigningPublicKey, _Mapping]] = ..., is_root_delegation: bool = ..., can_sign_all_mappings: _Optional[_Union[NamespaceDelegation.CanSignAllMappings, _Mapping]] = ..., can_sign_all_but_namespace_delegations: _Optional[_Union[NamespaceDelegation.CanSignAllButNamespaceDelegations, _Mapping]] = ..., can_sign_specific_mapings: _Optional[_Union[NamespaceDelegation.CanSignSpecificMappings, _Mapping]] = ...) -> None: ...

class DecentralizedNamespaceDefinition(_message.Message):
    __slots__ = ("decentralized_namespace", "threshold", "owners")
    DECENTRALIZED_NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    OWNERS_FIELD_NUMBER: _ClassVar[int]
    decentralized_namespace: str
    threshold: int
    owners: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, decentralized_namespace: _Optional[str] = ..., threshold: _Optional[int] = ..., owners: _Optional[_Iterable[str]] = ...) -> None: ...

class OwnerToKeyMapping(_message.Message):
    __slots__ = ("member", "public_keys")
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    member: str
    public_keys: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.PublicKey]
    def __init__(self, member: _Optional[str] = ..., public_keys: _Optional[_Iterable[_Union[_crypto_pb2.PublicKey, _Mapping]]] = ...) -> None: ...

class PartyToKeyMapping(_message.Message):
    __slots__ = ("party", "threshold", "signing_keys")
    PARTY_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    SIGNING_KEYS_FIELD_NUMBER: _ClassVar[int]
    party: str
    threshold: int
    signing_keys: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.SigningPublicKey]
    def __init__(self, party: _Optional[str] = ..., threshold: _Optional[int] = ..., signing_keys: _Optional[_Iterable[_Union[_crypto_pb2.SigningPublicKey, _Mapping]]] = ...) -> None: ...

class SynchronizerTrustCertificate(_message.Message):
    __slots__ = ("participant_uid", "synchronizer_id", "feature_flags")
    PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    FEATURE_FLAGS_FIELD_NUMBER: _ClassVar[int]
    participant_uid: str
    synchronizer_id: str
    feature_flags: _containers.RepeatedScalarFieldContainer[Enums.ParticipantFeatureFlag]
    def __init__(self, participant_uid: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., feature_flags: _Optional[_Iterable[_Union[Enums.ParticipantFeatureFlag, str]]] = ...) -> None: ...

class ParticipantSynchronizerPermission(_message.Message):
    __slots__ = ("synchronizer_id", "participant_uid", "permission", "limits", "login_after")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    PERMISSION_FIELD_NUMBER: _ClassVar[int]
    LIMITS_FIELD_NUMBER: _ClassVar[int]
    LOGIN_AFTER_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    participant_uid: str
    permission: Enums.ParticipantPermission
    limits: _synchronizer_parameters_pb2.ParticipantSynchronizerLimits
    login_after: int
    def __init__(self, synchronizer_id: _Optional[str] = ..., participant_uid: _Optional[str] = ..., permission: _Optional[_Union[Enums.ParticipantPermission, str]] = ..., limits: _Optional[_Union[_synchronizer_parameters_pb2.ParticipantSynchronizerLimits, _Mapping]] = ..., login_after: _Optional[int] = ...) -> None: ...

class PartyHostingLimits(_message.Message):
    __slots__ = ("synchronizer_id", "party")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    PARTY_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    party: str
    def __init__(self, synchronizer_id: _Optional[str] = ..., party: _Optional[str] = ...) -> None: ...

class VettedPackages(_message.Message):
    __slots__ = ("participant_uid", "package_ids", "packages")
    class VettedPackage(_message.Message):
        __slots__ = ("package_id", "valid_from_inclusive", "valid_until_exclusive")
        PACKAGE_ID_FIELD_NUMBER: _ClassVar[int]
        VALID_FROM_INCLUSIVE_FIELD_NUMBER: _ClassVar[int]
        VALID_UNTIL_EXCLUSIVE_FIELD_NUMBER: _ClassVar[int]
        package_id: str
        valid_from_inclusive: _timestamp_pb2.Timestamp
        valid_until_exclusive: _timestamp_pb2.Timestamp
        def __init__(self, package_id: _Optional[str] = ..., valid_from_inclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., valid_until_exclusive: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_IDS_FIELD_NUMBER: _ClassVar[int]
    PACKAGES_FIELD_NUMBER: _ClassVar[int]
    participant_uid: str
    package_ids: _containers.RepeatedScalarFieldContainer[str]
    packages: _containers.RepeatedCompositeFieldContainer[VettedPackages.VettedPackage]
    def __init__(self, participant_uid: _Optional[str] = ..., package_ids: _Optional[_Iterable[str]] = ..., packages: _Optional[_Iterable[_Union[VettedPackages.VettedPackage, _Mapping]]] = ...) -> None: ...

class PartyToParticipant(_message.Message):
    __slots__ = ("party", "threshold", "participants", "party_signing_keys")
    class HostingParticipant(_message.Message):
        __slots__ = ("participant_uid", "permission", "onboarding")
        class Onboarding(_message.Message):
            __slots__ = ()
            def __init__(self) -> None: ...
        PARTICIPANT_UID_FIELD_NUMBER: _ClassVar[int]
        PERMISSION_FIELD_NUMBER: _ClassVar[int]
        ONBOARDING_FIELD_NUMBER: _ClassVar[int]
        participant_uid: str
        permission: Enums.ParticipantPermission
        onboarding: PartyToParticipant.HostingParticipant.Onboarding
        def __init__(self, participant_uid: _Optional[str] = ..., permission: _Optional[_Union[Enums.ParticipantPermission, str]] = ..., onboarding: _Optional[_Union[PartyToParticipant.HostingParticipant.Onboarding, _Mapping]] = ...) -> None: ...
    PARTY_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANTS_FIELD_NUMBER: _ClassVar[int]
    PARTY_SIGNING_KEYS_FIELD_NUMBER: _ClassVar[int]
    party: str
    threshold: int
    participants: _containers.RepeatedCompositeFieldContainer[PartyToParticipant.HostingParticipant]
    party_signing_keys: _crypto_pb2.SigningKeysWithThreshold
    def __init__(self, party: _Optional[str] = ..., threshold: _Optional[int] = ..., participants: _Optional[_Iterable[_Union[PartyToParticipant.HostingParticipant, _Mapping]]] = ..., party_signing_keys: _Optional[_Union[_crypto_pb2.SigningKeysWithThreshold, _Mapping]] = ...) -> None: ...

class SynchronizerParametersState(_message.Message):
    __slots__ = ("synchronizer_id", "synchronizer_parameters")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    synchronizer_parameters: _synchronizer_parameters_pb2.DynamicSynchronizerParameters
    def __init__(self, synchronizer_id: _Optional[str] = ..., synchronizer_parameters: _Optional[_Union[_synchronizer_parameters_pb2.DynamicSynchronizerParameters, _Mapping]] = ...) -> None: ...

class DynamicSequencingParametersState(_message.Message):
    __slots__ = ("synchronizer_id", "sequencing_parameters")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    SEQUENCING_PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    sequencing_parameters: _sequencing_parameters_pb2.DynamicSequencingParameters
    def __init__(self, synchronizer_id: _Optional[str] = ..., sequencing_parameters: _Optional[_Union[_sequencing_parameters_pb2.DynamicSequencingParameters, _Mapping]] = ...) -> None: ...

class MediatorSynchronizerState(_message.Message):
    __slots__ = ("synchronizer_id", "group", "threshold", "active", "observers")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBSERVERS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    group: int
    threshold: int
    active: _containers.RepeatedScalarFieldContainer[str]
    observers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, synchronizer_id: _Optional[str] = ..., group: _Optional[int] = ..., threshold: _Optional[int] = ..., active: _Optional[_Iterable[str]] = ..., observers: _Optional[_Iterable[str]] = ...) -> None: ...

class SequencerSynchronizerState(_message.Message):
    __slots__ = ("synchronizer_id", "threshold", "active", "observers")
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBSERVERS_FIELD_NUMBER: _ClassVar[int]
    synchronizer_id: str
    threshold: int
    active: _containers.RepeatedScalarFieldContainer[str]
    observers: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, synchronizer_id: _Optional[str] = ..., threshold: _Optional[int] = ..., active: _Optional[_Iterable[str]] = ..., observers: _Optional[_Iterable[str]] = ...) -> None: ...

class SynchronizerUpgradeAnnouncement(_message.Message):
    __slots__ = ("successor_physical_synchronizer_id", "upgrade_time")
    SUCCESSOR_PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    UPGRADE_TIME_FIELD_NUMBER: _ClassVar[int]
    successor_physical_synchronizer_id: str
    upgrade_time: _timestamp_pb2.Timestamp
    def __init__(self, successor_physical_synchronizer_id: _Optional[str] = ..., upgrade_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class SequencerConnectionSuccessor(_message.Message):
    __slots__ = ("sequencer_id", "synchronizer_id", "connection")
    class SequencerConnection(_message.Message):
        __slots__ = ("grpc",)
        class Grpc(_message.Message):
            __slots__ = ("endpoints", "custom_trust_certificates")
            ENDPOINTS_FIELD_NUMBER: _ClassVar[int]
            CUSTOM_TRUST_CERTIFICATES_FIELD_NUMBER: _ClassVar[int]
            endpoints: _containers.RepeatedScalarFieldContainer[str]
            custom_trust_certificates: bytes
            def __init__(self, endpoints: _Optional[_Iterable[str]] = ..., custom_trust_certificates: _Optional[bytes] = ...) -> None: ...
        GRPC_FIELD_NUMBER: _ClassVar[int]
        grpc: SequencerConnectionSuccessor.SequencerConnection.Grpc
        def __init__(self, grpc: _Optional[_Union[SequencerConnectionSuccessor.SequencerConnection.Grpc, _Mapping]] = ...) -> None: ...
    SEQUENCER_ID_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_FIELD_NUMBER: _ClassVar[int]
    sequencer_id: str
    synchronizer_id: str
    connection: SequencerConnectionSuccessor.SequencerConnection
    def __init__(self, sequencer_id: _Optional[str] = ..., synchronizer_id: _Optional[str] = ..., connection: _Optional[_Union[SequencerConnectionSuccessor.SequencerConnection, _Mapping]] = ...) -> None: ...

class TopologyMapping(_message.Message):
    __slots__ = ("namespace_delegation", "decentralized_namespace_definition", "owner_to_key_mapping", "synchronizer_trust_certificate", "participant_permission", "party_hosting_limits", "vetted_packages", "party_to_participant", "synchronizer_parameters_state", "mediator_synchronizer_state", "sequencer_synchronizer_state", "sequencing_dynamic_parameters_state", "party_to_key_mapping", "synchronizer_upgrade_announcement", "sequencer_connection_successor")
    NAMESPACE_DELEGATION_FIELD_NUMBER: _ClassVar[int]
    DECENTRALIZED_NAMESPACE_DEFINITION_FIELD_NUMBER: _ClassVar[int]
    OWNER_TO_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_TRUST_CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    PARTICIPANT_PERMISSION_FIELD_NUMBER: _ClassVar[int]
    PARTY_HOSTING_LIMITS_FIELD_NUMBER: _ClassVar[int]
    VETTED_PACKAGES_FIELD_NUMBER: _ClassVar[int]
    PARTY_TO_PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_PARAMETERS_STATE_FIELD_NUMBER: _ClassVar[int]
    MEDIATOR_SYNCHRONIZER_STATE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_SYNCHRONIZER_STATE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCING_DYNAMIC_PARAMETERS_STATE_FIELD_NUMBER: _ClassVar[int]
    PARTY_TO_KEY_MAPPING_FIELD_NUMBER: _ClassVar[int]
    SYNCHRONIZER_UPGRADE_ANNOUNCEMENT_FIELD_NUMBER: _ClassVar[int]
    SEQUENCER_CONNECTION_SUCCESSOR_FIELD_NUMBER: _ClassVar[int]
    namespace_delegation: NamespaceDelegation
    decentralized_namespace_definition: DecentralizedNamespaceDefinition
    owner_to_key_mapping: OwnerToKeyMapping
    synchronizer_trust_certificate: SynchronizerTrustCertificate
    participant_permission: ParticipantSynchronizerPermission
    party_hosting_limits: PartyHostingLimits
    vetted_packages: VettedPackages
    party_to_participant: PartyToParticipant
    synchronizer_parameters_state: SynchronizerParametersState
    mediator_synchronizer_state: MediatorSynchronizerState
    sequencer_synchronizer_state: SequencerSynchronizerState
    sequencing_dynamic_parameters_state: DynamicSequencingParametersState
    party_to_key_mapping: PartyToKeyMapping
    synchronizer_upgrade_announcement: SynchronizerUpgradeAnnouncement
    sequencer_connection_successor: SequencerConnectionSuccessor
    def __init__(self, namespace_delegation: _Optional[_Union[NamespaceDelegation, _Mapping]] = ..., decentralized_namespace_definition: _Optional[_Union[DecentralizedNamespaceDefinition, _Mapping]] = ..., owner_to_key_mapping: _Optional[_Union[OwnerToKeyMapping, _Mapping]] = ..., synchronizer_trust_certificate: _Optional[_Union[SynchronizerTrustCertificate, _Mapping]] = ..., participant_permission: _Optional[_Union[ParticipantSynchronizerPermission, _Mapping]] = ..., party_hosting_limits: _Optional[_Union[PartyHostingLimits, _Mapping]] = ..., vetted_packages: _Optional[_Union[VettedPackages, _Mapping]] = ..., party_to_participant: _Optional[_Union[PartyToParticipant, _Mapping]] = ..., synchronizer_parameters_state: _Optional[_Union[SynchronizerParametersState, _Mapping]] = ..., mediator_synchronizer_state: _Optional[_Union[MediatorSynchronizerState, _Mapping]] = ..., sequencer_synchronizer_state: _Optional[_Union[SequencerSynchronizerState, _Mapping]] = ..., sequencing_dynamic_parameters_state: _Optional[_Union[DynamicSequencingParametersState, _Mapping]] = ..., party_to_key_mapping: _Optional[_Union[PartyToKeyMapping, _Mapping]] = ..., synchronizer_upgrade_announcement: _Optional[_Union[SynchronizerUpgradeAnnouncement, _Mapping]] = ..., sequencer_connection_successor: _Optional[_Union[SequencerConnectionSuccessor, _Mapping]] = ...) -> None: ...

class TopologyTransaction(_message.Message):
    __slots__ = ("operation", "serial", "mapping")
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    SERIAL_FIELD_NUMBER: _ClassVar[int]
    MAPPING_FIELD_NUMBER: _ClassVar[int]
    operation: Enums.TopologyChangeOp
    serial: int
    mapping: TopologyMapping
    def __init__(self, operation: _Optional[_Union[Enums.TopologyChangeOp, str]] = ..., serial: _Optional[int] = ..., mapping: _Optional[_Union[TopologyMapping, _Mapping]] = ...) -> None: ...

class MultiTransactionSignatures(_message.Message):
    __slots__ = ("transaction_hashes", "signatures")
    TRANSACTION_HASHES_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    transaction_hashes: _containers.RepeatedScalarFieldContainer[bytes]
    signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    def __init__(self, transaction_hashes: _Optional[_Iterable[bytes]] = ..., signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ...) -> None: ...

class SignedTopologyTransaction(_message.Message):
    __slots__ = ("transaction", "signatures", "proposal", "multi_transaction_signatures")
    TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    PROPOSAL_FIELD_NUMBER: _ClassVar[int]
    MULTI_TRANSACTION_SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    transaction: bytes
    signatures: _containers.RepeatedCompositeFieldContainer[_crypto_pb2.Signature]
    proposal: bool
    multi_transaction_signatures: _containers.RepeatedCompositeFieldContainer[MultiTransactionSignatures]
    def __init__(self, transaction: _Optional[bytes] = ..., signatures: _Optional[_Iterable[_Union[_crypto_pb2.Signature, _Mapping]]] = ..., proposal: bool = ..., multi_transaction_signatures: _Optional[_Iterable[_Union[MultiTransactionSignatures, _Mapping]]] = ...) -> None: ...

class SignedTopologyTransactions(_message.Message):
    __slots__ = ("signed_transaction",)
    SIGNED_TRANSACTION_FIELD_NUMBER: _ClassVar[int]
    signed_transaction: _containers.RepeatedScalarFieldContainer[bytes]
    def __init__(self, signed_transaction: _Optional[_Iterable[bytes]] = ...) -> None: ...

class TopologyTransactionsBroadcast(_message.Message):
    __slots__ = ("physical_synchronizer_id", "signed_transactions")
    PHYSICAL_SYNCHRONIZER_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNED_TRANSACTIONS_FIELD_NUMBER: _ClassVar[int]
    physical_synchronizer_id: str
    signed_transactions: SignedTopologyTransactions
    def __init__(self, physical_synchronizer_id: _Optional[str] = ..., signed_transactions: _Optional[_Union[SignedTopologyTransactions, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
import datetime

from ......crypto.v30 import crypto_pb2 as _crypto_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class BftOrderingMessage(_message.Message):
    __slots__ = ("trace_context", "body", "sent_by", "sent_at")
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    BODY_FIELD_NUMBER: _ClassVar[int]
    SENT_BY_FIELD_NUMBER: _ClassVar[int]
    SENT_AT_FIELD_NUMBER: _ClassVar[int]
    trace_context: str
    body: BftOrderingMessageBody
    sent_by: str
    sent_at: _timestamp_pb2.Timestamp
    def __init__(self, trace_context: _Optional[str] = ..., body: _Optional[_Union[BftOrderingMessageBody, _Mapping]] = ..., sent_by: _Optional[str] = ..., sent_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class BftOrderingMessageBody(_message.Message):
    __slots__ = ("availability_message", "consensus_message", "state_transfer_message", "retransmission_message", "connection_opened")
    AVAILABILITY_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    CONSENSUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    STATE_TRANSFER_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    RETRANSMISSION_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    CONNECTION_OPENED_FIELD_NUMBER: _ClassVar[int]
    availability_message: SignedMessage
    consensus_message: SignedMessage
    state_transfer_message: SignedMessage
    retransmission_message: RetransmissionMessage
    connection_opened: ConnectionOpened
    def __init__(self, availability_message: _Optional[_Union[SignedMessage, _Mapping]] = ..., consensus_message: _Optional[_Union[SignedMessage, _Mapping]] = ..., state_transfer_message: _Optional[_Union[SignedMessage, _Mapping]] = ..., retransmission_message: _Optional[_Union[RetransmissionMessage, _Mapping]] = ..., connection_opened: _Optional[_Union[ConnectionOpened, _Mapping]] = ...) -> None: ...

class SignedMessage(_message.Message):
    __slots__ = ("message", "signature")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    message: bytes
    signature: _crypto_pb2.Signature
    def __init__(self, message: _Optional[bytes] = ..., signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., **kwargs) -> None: ...

class ConnectionOpened(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class AvailabilityMessage(_message.Message):
    __slots__ = ("ping", "store_request", "store_response", "batch_request", "batch_response")
    PING_FIELD_NUMBER: _ClassVar[int]
    STORE_REQUEST_FIELD_NUMBER: _ClassVar[int]
    STORE_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    BATCH_REQUEST_FIELD_NUMBER: _ClassVar[int]
    BATCH_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    ping: _empty_pb2.Empty
    store_request: StoreRequest
    store_response: StoreResponse
    batch_request: BatchRequest
    batch_response: BatchResponse
    def __init__(self, ping: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., store_request: _Optional[_Union[StoreRequest, _Mapping]] = ..., store_response: _Optional[_Union[StoreResponse, _Mapping]] = ..., batch_request: _Optional[_Union[BatchRequest, _Mapping]] = ..., batch_response: _Optional[_Union[BatchResponse, _Mapping]] = ...) -> None: ...

class StoreRequest(_message.Message):
    __slots__ = ("batch_id", "batch")
    BATCH_ID_FIELD_NUMBER: _ClassVar[int]
    BATCH_FIELD_NUMBER: _ClassVar[int]
    batch_id: bytes
    batch: Batch
    def __init__(self, batch_id: _Optional[bytes] = ..., batch: _Optional[_Union[Batch, _Mapping]] = ...) -> None: ...

class Batch(_message.Message):
    __slots__ = ("ordering_requests", "epoch_number")
    ORDERING_REQUESTS_FIELD_NUMBER: _ClassVar[int]
    EPOCH_NUMBER_FIELD_NUMBER: _ClassVar[int]
    ordering_requests: _containers.RepeatedCompositeFieldContainer[OrderingRequest]
    epoch_number: int
    def __init__(self, ordering_requests: _Optional[_Iterable[_Union[OrderingRequest, _Mapping]]] = ..., epoch_number: _Optional[int] = ...) -> None: ...

class OrderingRequest(_message.Message):
    __slots__ = ("trace_context", "tag", "payload", "ordering_start_instant")
    TRACE_CONTEXT_FIELD_NUMBER: _ClassVar[int]
    TAG_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    ORDERING_START_INSTANT_FIELD_NUMBER: _ClassVar[int]
    trace_context: str
    tag: str
    payload: bytes
    ordering_start_instant: _timestamp_pb2.Timestamp
    def __init__(self, trace_context: _Optional[str] = ..., tag: _Optional[str] = ..., payload: _Optional[bytes] = ..., ordering_start_instant: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class StoreResponse(_message.Message):
    __slots__ = ("batch_id", "signature")
    BATCH_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    batch_id: bytes
    signature: _crypto_pb2.Signature
    def __init__(self, batch_id: _Optional[bytes] = ..., signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ...) -> None: ...

class BatchRequest(_message.Message):
    __slots__ = ("batch_id",)
    BATCH_ID_FIELD_NUMBER: _ClassVar[int]
    batch_id: bytes
    def __init__(self, batch_id: _Optional[bytes] = ...) -> None: ...

class BatchResponse(_message.Message):
    __slots__ = ("batch_id", "batch")
    BATCH_ID_FIELD_NUMBER: _ClassVar[int]
    BATCH_FIELD_NUMBER: _ClassVar[int]
    batch_id: bytes
    batch: Batch
    def __init__(self, batch_id: _Optional[bytes] = ..., batch: _Optional[_Union[Batch, _Mapping]] = ...) -> None: ...

class OrderingBlock(_message.Message):
    __slots__ = ("proofs",)
    PROOFS_FIELD_NUMBER: _ClassVar[int]
    proofs: _containers.RepeatedCompositeFieldContainer[ProofOfAvailability]
    def __init__(self, proofs: _Optional[_Iterable[_Union[ProofOfAvailability, _Mapping]]] = ...) -> None: ...

class ProofOfAvailability(_message.Message):
    __slots__ = ("batch_id", "acks", "epoch_number")
    BATCH_ID_FIELD_NUMBER: _ClassVar[int]
    ACKS_FIELD_NUMBER: _ClassVar[int]
    EPOCH_NUMBER_FIELD_NUMBER: _ClassVar[int]
    batch_id: bytes
    acks: _containers.RepeatedCompositeFieldContainer[AvailabilityAck]
    epoch_number: int
    def __init__(self, batch_id: _Optional[bytes] = ..., acks: _Optional[_Iterable[_Union[AvailabilityAck, _Mapping]]] = ..., epoch_number: _Optional[int] = ...) -> None: ...

class AvailabilityAck(_message.Message):
    __slots__ = ("signature",)
    FROM_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    signature: _crypto_pb2.Signature
    def __init__(self, signature: _Optional[_Union[_crypto_pb2.Signature, _Mapping]] = ..., **kwargs) -> None: ...

class ConsensusMessage(_message.Message):
    __slots__ = ("block_metadata", "view_number", "pre_prepare", "prepare", "commit", "view_change", "new_view")
    BLOCK_METADATA_FIELD_NUMBER: _ClassVar[int]
    VIEW_NUMBER_FIELD_NUMBER: _ClassVar[int]
    FROM_FIELD_NUMBER: _ClassVar[int]
    PRE_PREPARE_FIELD_NUMBER: _ClassVar[int]
    PREPARE_FIELD_NUMBER: _ClassVar[int]
    COMMIT_FIELD_NUMBER: _ClassVar[int]
    VIEW_CHANGE_FIELD_NUMBER: _ClassVar[int]
    NEW_VIEW_FIELD_NUMBER: _ClassVar[int]
    block_metadata: BlockMetadata
    view_number: int
    pre_prepare: PrePrepare
    prepare: Prepare
    commit: Commit
    view_change: ViewChange
    new_view: NewView
    def __init__(self, block_metadata: _Optional[_Union[BlockMetadata, _Mapping]] = ..., view_number: _Optional[int] = ..., pre_prepare: _Optional[_Union[PrePrepare, _Mapping]] = ..., prepare: _Optional[_Union[Prepare, _Mapping]] = ..., commit: _Optional[_Union[Commit, _Mapping]] = ..., view_change: _Optional[_Union[ViewChange, _Mapping]] = ..., new_view: _Optional[_Union[NewView, _Mapping]] = ..., **kwargs) -> None: ...

class BlockMetadata(_message.Message):
    __slots__ = ("epoch_number", "block_number")
    EPOCH_NUMBER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_NUMBER_FIELD_NUMBER: _ClassVar[int]
    epoch_number: int
    block_number: int
    def __init__(self, epoch_number: _Optional[int] = ..., block_number: _Optional[int] = ...) -> None: ...

class PrePrepare(_message.Message):
    __slots__ = ("block", "bft_time_canonical_commit_set")
    BLOCK_FIELD_NUMBER: _ClassVar[int]
    BFT_TIME_CANONICAL_COMMIT_SET_FIELD_NUMBER: _ClassVar[int]
    block: OrderingBlock
    bft_time_canonical_commit_set: CanonicalCommitSet
    def __init__(self, block: _Optional[_Union[OrderingBlock, _Mapping]] = ..., bft_time_canonical_commit_set: _Optional[_Union[CanonicalCommitSet, _Mapping]] = ...) -> None: ...

class Prepare(_message.Message):
    __slots__ = ("block_hash",)
    BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    block_hash: bytes
    def __init__(self, block_hash: _Optional[bytes] = ...) -> None: ...

class Commit(_message.Message):
    __slots__ = ("block_hash", "local_timestamp")
    BLOCK_HASH_FIELD_NUMBER: _ClassVar[int]
    LOCAL_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    block_hash: bytes
    local_timestamp: int
    def __init__(self, block_hash: _Optional[bytes] = ..., local_timestamp: _Optional[int] = ...) -> None: ...

class ViewChange(_message.Message):
    __slots__ = ("consensus_certs",)
    CONSENSUS_CERTS_FIELD_NUMBER: _ClassVar[int]
    consensus_certs: _containers.RepeatedCompositeFieldContainer[ConsensusCertificate]
    def __init__(self, consensus_certs: _Optional[_Iterable[_Union[ConsensusCertificate, _Mapping]]] = ...) -> None: ...

class NewView(_message.Message):
    __slots__ = ("view_changes", "pre_prepares")
    VIEW_CHANGES_FIELD_NUMBER: _ClassVar[int]
    PRE_PREPARES_FIELD_NUMBER: _ClassVar[int]
    view_changes: _containers.RepeatedCompositeFieldContainer[SignedMessage]
    pre_prepares: _containers.RepeatedCompositeFieldContainer[SignedMessage]
    def __init__(self, view_changes: _Optional[_Iterable[_Union[SignedMessage, _Mapping]]] = ..., pre_prepares: _Optional[_Iterable[_Union[SignedMessage, _Mapping]]] = ...) -> None: ...

class CanonicalCommitSet(_message.Message):
    __slots__ = ("canonical_commits",)
    CANONICAL_COMMITS_FIELD_NUMBER: _ClassVar[int]
    canonical_commits: _containers.RepeatedCompositeFieldContainer[SignedMessage]
    def __init__(self, canonical_commits: _Optional[_Iterable[_Union[SignedMessage, _Mapping]]] = ...) -> None: ...

class ConsensusCertificate(_message.Message):
    __slots__ = ("prepare_certificate", "commit_certificate")
    PREPARE_CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    COMMIT_CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    prepare_certificate: PrepareCertificate
    commit_certificate: CommitCertificate
    def __init__(self, prepare_certificate: _Optional[_Union[PrepareCertificate, _Mapping]] = ..., commit_certificate: _Optional[_Union[CommitCertificate, _Mapping]] = ...) -> None: ...

class PrepareCertificate(_message.Message):
    __slots__ = ("pre_prepare", "prepares")
    PRE_PREPARE_FIELD_NUMBER: _ClassVar[int]
    PREPARES_FIELD_NUMBER: _ClassVar[int]
    pre_prepare: SignedMessage
    prepares: _containers.RepeatedCompositeFieldContainer[SignedMessage]
    def __init__(self, pre_prepare: _Optional[_Union[SignedMessage, _Mapping]] = ..., prepares: _Optional[_Iterable[_Union[SignedMessage, _Mapping]]] = ...) -> None: ...

class CommitCertificate(_message.Message):
    __slots__ = ("pre_prepare", "commits")
    PRE_PREPARE_FIELD_NUMBER: _ClassVar[int]
    COMMITS_FIELD_NUMBER: _ClassVar[int]
    pre_prepare: SignedMessage
    commits: _containers.RepeatedCompositeFieldContainer[SignedMessage]
    def __init__(self, pre_prepare: _Optional[_Union[SignedMessage, _Mapping]] = ..., commits: _Optional[_Iterable[_Union[SignedMessage, _Mapping]]] = ...) -> None: ...

class RetransmissionMessage(_message.Message):
    __slots__ = ("retransmission_request", "retransmission_response")
    RETRANSMISSION_REQUEST_FIELD_NUMBER: _ClassVar[int]
    RETRANSMISSION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    retransmission_request: SignedMessage
    retransmission_response: RetransmissionResponse
    def __init__(self, retransmission_request: _Optional[_Union[SignedMessage, _Mapping]] = ..., retransmission_response: _Optional[_Union[RetransmissionResponse, _Mapping]] = ...) -> None: ...

class RetransmissionResponse(_message.Message):
    __slots__ = ("commit_certificates",)
    COMMIT_CERTIFICATES_FIELD_NUMBER: _ClassVar[int]
    commit_certificates: _containers.RepeatedCompositeFieldContainer[CommitCertificate]
    def __init__(self, commit_certificates: _Optional[_Iterable[_Union[CommitCertificate, _Mapping]]] = ...) -> None: ...

class EpochStatus(_message.Message):
    __slots__ = ("epoch_number", "segments")
    EPOCH_NUMBER_FIELD_NUMBER: _ClassVar[int]
    SEGMENTS_FIELD_NUMBER: _ClassVar[int]
    epoch_number: int
    segments: _containers.RepeatedCompositeFieldContainer[SegmentStatus]
    def __init__(self, epoch_number: _Optional[int] = ..., segments: _Optional[_Iterable[_Union[SegmentStatus, _Mapping]]] = ...) -> None: ...

class SegmentStatus(_message.Message):
    __slots__ = ("complete", "in_view_change", "in_progress")
    COMPLETE_FIELD_NUMBER: _ClassVar[int]
    IN_VIEW_CHANGE_FIELD_NUMBER: _ClassVar[int]
    IN_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    complete: _empty_pb2.Empty
    in_view_change: SegmentInViewChange
    in_progress: SegmentInProgress
    def __init__(self, complete: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., in_view_change: _Optional[_Union[SegmentInViewChange, _Mapping]] = ..., in_progress: _Optional[_Union[SegmentInProgress, _Mapping]] = ...) -> None: ...

class SegmentInViewChange(_message.Message):
    __slots__ = ("view_number", "view_change_messages_present", "are_blocks_complete")
    VIEW_NUMBER_FIELD_NUMBER: _ClassVar[int]
    VIEW_CHANGE_MESSAGES_PRESENT_FIELD_NUMBER: _ClassVar[int]
    ARE_BLOCKS_COMPLETE_FIELD_NUMBER: _ClassVar[int]
    view_number: int
    view_change_messages_present: _containers.RepeatedScalarFieldContainer[bool]
    are_blocks_complete: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, view_number: _Optional[int] = ..., view_change_messages_present: _Optional[_Iterable[bool]] = ..., are_blocks_complete: _Optional[_Iterable[bool]] = ...) -> None: ...

class SegmentInProgress(_message.Message):
    __slots__ = ("view_number", "block_statuses")
    VIEW_NUMBER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_STATUSES_FIELD_NUMBER: _ClassVar[int]
    view_number: int
    block_statuses: _containers.RepeatedCompositeFieldContainer[BlockStatus]
    def __init__(self, view_number: _Optional[int] = ..., block_statuses: _Optional[_Iterable[_Union[BlockStatus, _Mapping]]] = ...) -> None: ...

class BlockStatus(_message.Message):
    __slots__ = ("complete", "in_progress")
    COMPLETE_FIELD_NUMBER: _ClassVar[int]
    IN_PROGRESS_FIELD_NUMBER: _ClassVar[int]
    complete: _empty_pb2.Empty
    in_progress: BlockInProgress
    def __init__(self, complete: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ..., in_progress: _Optional[_Union[BlockInProgress, _Mapping]] = ...) -> None: ...

class BlockInProgress(_message.Message):
    __slots__ = ("pre_prepared", "prepares_present", "commits_present")
    PRE_PREPARED_FIELD_NUMBER: _ClassVar[int]
    PREPARES_PRESENT_FIELD_NUMBER: _ClassVar[int]
    COMMITS_PRESENT_FIELD_NUMBER: _ClassVar[int]
    pre_prepared: bool
    prepares_present: _containers.RepeatedScalarFieldContainer[bool]
    commits_present: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, pre_prepared: bool = ..., prepares_present: _Optional[_Iterable[bool]] = ..., commits_present: _Optional[_Iterable[bool]] = ...) -> None: ...

class StateTransferMessage(_message.Message):
    __slots__ = ("block_request", "block_response")
    BLOCK_REQUEST_FIELD_NUMBER: _ClassVar[int]
    BLOCK_RESPONSE_FIELD_NUMBER: _ClassVar[int]
    block_request: BlockTransferRequest
    block_response: BlockTransferResponse
    def __init__(self, block_request: _Optional[_Union[BlockTransferRequest, _Mapping]] = ..., block_response: _Optional[_Union[BlockTransferResponse, _Mapping]] = ...) -> None: ...

class BlockTransferRequest(_message.Message):
    __slots__ = ("epoch",)
    EPOCH_FIELD_NUMBER: _ClassVar[int]
    epoch: int
    def __init__(self, epoch: _Optional[int] = ...) -> None: ...

class BlockTransferResponse(_message.Message):
    __slots__ = ("commit_certificate",)
    COMMIT_CERTIFICATE_FIELD_NUMBER: _ClassVar[int]
    commit_certificate: CommitCertificate
    def __init__(self, commit_certificate: _Optional[_Union[CommitCertificate, _Mapping]] = ...) -> None: ...



# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30/bft_ordering_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30/bft_ordering_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ......crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\ndcom/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30/bft_ordering_service.proto\x12Icom.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfe\x01\n\x12\x42\x66tOrderingMessage\x12#\n\rtrace_context\x18\x01 \x01(\tR\x0ctraceContext\x12u\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BftOrderingMessageBodyR\x04\x62ody\x12\x17\n\x07sent_by\x18\x03 \x01(\tR\x06sentBy\x12\x33\n\x07sent_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x06sentAt\"\xf9\x05\n\x16\x42\x66tOrderingMessageBody\x12\x8d\x01\n\x14\x61vailability_message\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageH\x00R\x13\x61vailabilityMessage\x12\x87\x01\n\x11\x63onsensus_message\x18\x02 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageH\x00R\x10\x63onsensusMessage\x12\x90\x01\n\x16state_transfer_message\x18\x03 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageH\x00R\x14stateTransferMessage\x12\x99\x01\n\x16retransmission_message\x18\x04 \x01(\x0b\x32`.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.RetransmissionMessageH\x00R\x15retransmissionMessage\x12\x8a\x01\n\x11\x63onnection_opened\x18\x05 \x01(\x0b\x32[.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.ConnectionOpenedH\x00R\x10\x63onnectionOpenedB\t\n\x07message\"\x8a\x01\n\rSignedMessage\x12\x18\n\x07message\x18\x01 \x01(\x0cR\x07message\x12\x12\n\x04\x66rom\x18\x02 \x01(\tR\x04\x66rom\x12K\n\tsignature\x18\x03 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\"\x12\n\x10\x43onnectionOpened\"\xd6\x04\n\x13\x41vailabilityMessage\x12,\n\x04ping\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x04ping\x12~\n\rstore_request\x18\x02 \x01(\x0b\x32W.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.StoreRequestH\x00R\x0cstoreRequest\x12\x81\x01\n\x0estore_response\x18\x03 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.StoreResponseH\x00R\rstoreResponse\x12~\n\rbatch_request\x18\x04 \x01(\x0b\x32W.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BatchRequestH\x00R\x0c\x62\x61tchRequest\x12\x81\x01\n\x0e\x62\x61tch_response\x18\x05 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BatchResponseH\x00R\rbatchResponseB\t\n\x07message\"\x91\x01\n\x0cStoreRequest\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\x12\x66\n\x05\x62\x61tch\x18\x02 \x01(\x0b\x32P.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BatchR\x05\x62\x61tch\"\xb4\x01\n\x05\x42\x61tch\x12\x87\x01\n\x11ordering_requests\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.OrderingRequestR\x10orderingRequests\x12!\n\x0c\x65poch_number\x18\x02 \x01(\x03R\x0b\x65pochNumber\"\xb4\x01\n\x0fOrderingRequest\x12#\n\rtrace_context\x18\x01 \x01(\tR\x0ctraceContext\x12\x10\n\x03tag\x18\x02 \x01(\tR\x03tag\x12\x18\n\x07payload\x18\x03 \x01(\x0cR\x07payload\x12P\n\x16ordering_start_instant\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x14orderingStartInstant\"w\n\rStoreResponse\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\x12K\n\tsignature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\")\n\x0c\x42\x61tchRequest\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\"\x92\x01\n\rBatchResponse\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\x12\x66\n\x05\x62\x61tch\x18\x02 \x01(\x0b\x32P.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BatchR\x05\x62\x61tch\"\x87\x01\n\rOrderingBlock\x12v\n\x06proofs\x18\x01 \x03(\x0b\x32^.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.ProofOfAvailabilityR\x06proofs\"\xc3\x01\n\x13ProofOfAvailability\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\x12n\n\x04\x61\x63ks\x18\x02 \x03(\x0b\x32Z.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.AvailabilityAckR\x04\x61\x63ks\x12!\n\x0c\x65poch_number\x18\x03 \x01(\x03R\x0b\x65pochNumber\"r\n\x0f\x41vailabilityAck\x12\x12\n\x04\x66rom\x18\x01 \x01(\tR\x04\x66rom\x12K\n\tsignature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\"\x95\x06\n\x10\x43onsensusMessage\x12\x7f\n\x0e\x62lock_metadata\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockMetadataR\rblockMetadata\x12\x1f\n\x0bview_number\x18\x02 \x01(\x03R\nviewNumber\x12\x12\n\x04\x66rom\x18\x03 \x01(\tR\x04\x66rom\x12x\n\x0bpre_prepare\x18\x04 \x01(\x0b\x32U.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.PrePrepareH\x00R\nprePrepare\x12n\n\x07prepare\x18\x05 \x01(\x0b\x32R.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.PrepareH\x00R\x07prepare\x12k\n\x06\x63ommit\x18\x06 \x01(\x0b\x32Q.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CommitH\x00R\x06\x63ommit\x12x\n\x0bview_change\x18\x07 \x01(\x0b\x32U.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.ViewChangeH\x00R\nviewChange\x12o\n\x08new_view\x18\x08 \x01(\x0b\x32R.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.NewViewH\x00R\x07newViewB\t\n\x07message\"U\n\rBlockMetadata\x12!\n\x0c\x65poch_number\x18\x01 \x01(\x03R\x0b\x65pochNumber\x12!\n\x0c\x62lock_number\x18\x02 \x01(\x03R\x0b\x62lockNumber\"\x9e\x02\n\nPrePrepare\x12n\n\x05\x62lock\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.OrderingBlockR\x05\x62lock\x12\x9f\x01\n\x1d\x62\x66t_time_canonical_commit_set\x18\x02 \x01(\x0b\x32].com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CanonicalCommitSetR\x19\x62\x66tTimeCanonicalCommitSet\"(\n\x07Prepare\x12\x1d\n\nblock_hash\x18\x01 \x01(\x0cR\tblockHash\"P\n\x06\x43ommit\x12\x1d\n\nblock_hash\x18\x01 \x01(\x0cR\tblockHash\x12\'\n\x0flocal_timestamp\x18\x02 \x01(\x03R\x0elocalTimestamp\"\x97\x01\n\nViewChange\x12\x88\x01\n\x0f\x63onsensus_certs\x18\x02 \x03(\x0b\x32_.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.ConsensusCertificateR\x0e\x63onsensusCerts\"\x83\x02\n\x07NewView\x12{\n\x0cview_changes\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x0bviewChanges\x12{\n\x0cpre_prepares\x18\x03 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x0bprePrepares\"\x9c\x01\n\x12\x43\x61nonicalCommitSet\x12\x85\x01\n\x11\x63\x61nonical_commits\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x10\x63\x61nonicalCommits\"\xc8\x02\n\x14\x43onsensusCertificate\x12\x90\x01\n\x13prepare_certificate\x18\x01 \x01(\x0b\x32].com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.PrepareCertificateH\x00R\x12prepareCertificate\x12\x8d\x01\n\x12\x63ommit_certificate\x18\x02 \x01(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CommitCertificateH\x00R\x11\x63ommitCertificateB\r\n\x0b\x63\x65rtificate\"\x85\x02\n\x12PrepareCertificate\x12y\n\x0bpre_prepare\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\nprePrepare\x12t\n\x08prepares\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x08prepares\"\x82\x02\n\x11\x43ommitCertificate\x12y\n\x0bpre_prepare\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\nprePrepare\x12r\n\x07\x63ommits\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x07\x63ommits\"\xd5\x02\n\x15RetransmissionMessage\x12\x91\x01\n\x16retransmission_request\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageH\x00R\x15retransmissionRequest\x12\x9c\x01\n\x17retransmission_response\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.RetransmissionResponseH\x00R\x16retransmissionResponseB\t\n\x07message\"\xa8\x01\n\x16RetransmissionResponse\x12\x8d\x01\n\x13\x63ommit_certificates\x18\x01 \x03(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CommitCertificateR\x12\x63ommitCertificates\"\xa6\x01\n\x0b\x45pochStatus\x12!\n\x0c\x65poch_number\x18\x01 \x01(\x03R\x0b\x65pochNumber\x12t\n\x08segments\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SegmentStatusR\x08segments\"\xd9\x02\n\rSegmentStatus\x12\x34\n\x08\x63omplete\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x08\x63omplete\x12\x86\x01\n\x0ein_view_change\x18\x02 \x01(\x0b\x32^.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SegmentInViewChangeH\x00R\x0cinViewChange\x12\x7f\n\x0bin_progress\x18\x03 \x01(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SegmentInProgressH\x00R\ninProgressB\x08\n\x06status\"\xa7\x01\n\x13SegmentInViewChange\x12\x1f\n\x0bview_number\x18\x01 \x01(\x03R\nviewNumber\x12?\n\x1cview_change_messages_present\x18\x02 \x03(\x08R\x19viewChangeMessagesPresent\x12.\n\x13\x61re_blocks_complete\x18\x03 \x03(\x08R\x11\x61reBlocksComplete\"\xb3\x01\n\x11SegmentInProgress\x12\x1f\n\x0bview_number\x18\x01 \x01(\x03R\nviewNumber\x12}\n\x0e\x62lock_statuses\x18\x02 \x03(\x0b\x32V.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockStatusR\rblockStatuses\"\xcc\x01\n\x0b\x42lockStatus\x12\x34\n\x08\x63omplete\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x08\x63omplete\x12}\n\x0bin_progress\x18\x02 \x01(\x0b\x32Z.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockInProgressH\x00R\ninProgressB\x08\n\x06status\"\x88\x01\n\x0f\x42lockInProgress\x12!\n\x0cpre_prepared\x18\x01 \x01(\x08R\x0bprePrepared\x12)\n\x10prepares_present\x18\x02 \x03(\x08R\x0fpreparesPresent\x12\'\n\x0f\x63ommits_present\x18\x03 \x03(\x08R\x0e\x63ommitsPresent\"\xb6\x02\n\x14StateTransferMessage\x12\x86\x01\n\rblock_request\x18\x01 \x01(\x0b\x32_.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockTransferRequestH\x00R\x0c\x62lockRequest\x12\x89\x01\n\x0e\x62lock_response\x18\x02 \x01(\x0b\x32`.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockTransferResponseH\x00R\rblockResponseB\t\n\x07message\",\n\x14\x42lockTransferRequest\x12\x14\n\x05\x65poch\x18\x01 \x01(\x03R\x05\x65poch\"\xc1\x01\n\x15\x42lockTransferResponse\x12\x90\x01\n\x12\x63ommit_certificate\x18\x01 \x01(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CommitCertificateH\x00R\x11\x63ommitCertificate\x88\x01\x01\x42\x15\n\x13_commit_certificate2\xe2\x01\n\x12\x42\x66tOrderingService\x12\xcb\x01\n\x07Receive\x12].com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BftOrderingMessage\x1a].com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BftOrderingMessage(\x01\x30\x01\x42zZxgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.bft_ordering_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Zxgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30'
  _globals['_BFTORDERINGMESSAGE']._serialized_start=291
  _globals['_BFTORDERINGMESSAGE']._serialized_end=545
  _globals['_BFTORDERINGMESSAGEBODY']._serialized_start=548
  _globals['_BFTORDERINGMESSAGEBODY']._serialized_end=1309
  _globals['_SIGNEDMESSAGE']._serialized_start=1312
  _globals['_SIGNEDMESSAGE']._serialized_end=1450
  _globals['_CONNECTIONOPENED']._serialized_start=1452
  _globals['_CONNECTIONOPENED']._serialized_end=1470
  _globals['_AVAILABILITYMESSAGE']._serialized_start=1473
  _globals['_AVAILABILITYMESSAGE']._serialized_end=2071
  _globals['_STOREREQUEST']._serialized_start=2074
  _globals['_STOREREQUEST']._serialized_end=2219
  _globals['_BATCH']._serialized_start=2222
  _globals['_BATCH']._serialized_end=2402
  _globals['_ORDERINGREQUEST']._serialized_start=2405
  _globals['_ORDERINGREQUEST']._serialized_end=2585
  _globals['_STORERESPONSE']._serialized_start=2587
  _globals['_STORERESPONSE']._serialized_end=2706
  _globals['_BATCHREQUEST']._serialized_start=2708
  _globals['_BATCHREQUEST']._serialized_end=2749
  _globals['_BATCHRESPONSE']._serialized_start=2752
  _globals['_BATCHRESPONSE']._serialized_end=2898
  _globals['_ORDERINGBLOCK']._serialized_start=2901
  _globals['_ORDERINGBLOCK']._serialized_end=3036
  _globals['_PROOFOFAVAILABILITY']._serialized_start=3039
  _globals['_PROOFOFAVAILABILITY']._serialized_end=3234
  _globals['_AVAILABILITYACK']._serialized_start=3236
  _globals['_AVAILABILITYACK']._serialized_end=3350
  _globals['_CONSENSUSMESSAGE']._serialized_start=3353
  _globals['_CONSENSUSMESSAGE']._serialized_end=4142
  _globals['_BLOCKMETADATA']._serialized_start=4144
  _globals['_BLOCKMETADATA']._serialized_end=4229
  _globals['_PREPREPARE']._serialized_start=4232
  _globals['_PREPREPARE']._serialized_end=4518
  _globals['_PREPARE']._serialized_start=4520
  _globals['_PREPARE']._serialized_end=4560
  _globals['_COMMIT']._serialized_start=4562
  _globals['_COMMIT']._serialized_end=4642
  _globals['_VIEWCHANGE']._serialized_start=4645
  _globals['_VIEWCHANGE']._serialized_end=4796
  _globals['_NEWVIEW']._serialized_start=4799
  _globals['_NEWVIEW']._serialized_end=5058
  _globals['_CANONICALCOMMITSET']._serialized_start=5061
  _globals['_CANONICALCOMMITSET']._serialized_end=5217
  _globals['_CONSENSUSCERTIFICATE']._serialized_start=5220
  _globals['_CONSENSUSCERTIFICATE']._serialized_end=5548
  _globals['_PREPARECERTIFICATE']._serialized_start=5551
  _globals['_PREPARECERTIFICATE']._serialized_end=5812
  _globals['_COMMITCERTIFICATE']._serialized_start=5815
  _globals['_COMMITCERTIFICATE']._serialized_end=6073
  _globals['_RETRANSMISSIONMESSAGE']._serialized_start=6076
  _globals['_RETRANSMISSIONMESSAGE']._serialized_end=6417
  _globals['_RETRANSMISSIONRESPONSE']._serialized_start=6420
  _globals['_RETRANSMISSIONRESPONSE']._serialized_end=6588
  _globals['_EPOCHSTATUS']._serialized_start=6591
  _globals['_EPOCHSTATUS']._serialized_end=6757
  _globals['_SEGMENTSTATUS']._serialized_start=6760
  _globals['_SEGMENTSTATUS']._serialized_end=7105
  _globals['_SEGMENTINVIEWCHANGE']._serialized_start=7108
  _globals['_SEGMENTINVIEWCHANGE']._serialized_end=7275
  _globals['_SEGMENTINPROGRESS']._serialized_start=7278
  _globals['_SEGMENTINPROGRESS']._serialized_end=7457
  _globals['_BLOCKSTATUS']._serialized_start=7460
  _globals['_BLOCKSTATUS']._serialized_end=7664
  _globals['_BLOCKINPROGRESS']._serialized_start=7667
  _globals['_BLOCKINPROGRESS']._serialized_end=7803
  _globals['_STATETRANSFERMESSAGE']._serialized_start=7806
  _globals['_STATETRANSFERMESSAGE']._serialized_end=8116
  _globals['_BLOCKTRANSFERREQUEST']._serialized_start=8118
  _globals['_BLOCKTRANSFERREQUEST']._serialized_end=8162
  _globals['_BLOCKTRANSFERRESPONSE']._serialized_start=8165
  _globals['_BLOCKTRANSFERRESPONSE']._serialized_end=8358
  _globals['_BFTORDERINGSERVICE']._serialized_start=8361
  _globals['_BFTORDERINGSERVICE']._serialized_end=8587
# @@protoc_insertion_point(module_scope)
